SystemOrganization addCategory: #'Seaside-Tests-Session'!

TestCase subclass: #WACurrentSessionTest
	instanceVariableNames: 'savedContinuation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACurrentSessionTest commentStamp: 'pmm 3/29/2008 12:34' prior: 0!
A WACurrentSessionTest is to make sure

WACurrentSession value

works as in Seaside 2.9 as it did in earlier versions.
!

!WACurrentSessionTest methodsFor: 'running' stamp: 'lr 4/9/2008 09:38'!
setUp
	super setUp.
	WACurrentRequestContext reset! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 9/13/2008 14:19'!
testBalancedContextContinuations
	"Cause the ensure blocks in WAContext to fire - use balanced nesting and things work fine"
	| x session alternateSession tertiarySession quatenarySession context |
	session := WASession new.
	alternateSession := WASession new.
	tertiarySession := WASession new.
	quatenarySession := WASession new.
	context := WARequestContext new.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: tertiarySession
				while: 
					[ self assert: WACurrentRequestContext value session == tertiarySession.
					WACurrentRequestContext value 
						push: session
						while: 
							[ x := WAContinuation currentDo: 
								[ :cc | 
								savedContinuation := cc.
								0 ].
							x == 0 
								ifTrue: [ self assert: WACurrentRequestContext value session == session ]
								ifFalse: 
									[ self assert: x = 1.
									self assert: WACurrentRequestContext value session == quatenarySession ] ].
					x == 0 ifTrue: 
						[ self assert: WACurrentRequestContext value session == tertiarySession ].
					x == 1 ifTrue: 
						[ self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: 
						[ WACurrentRequestContext value 
							push: quatenarySession
							while: [ savedContinuation value: 1 ] ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 9/13/2008 14:19'!
testContinuationInheritance
	"Verify that continuation inherits it's context from parent process"
	| x session alternateSession context |
	session := WASession new.
	alternateSession := WASession new.
	context := WARequestContext new.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 
						ifTrue: [ self assert: WACurrentRequestContext value session == session ]
						ifFalse: 
							[ self assert: x = 1.
							self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: [ savedContinuation value: 1 ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 9/13/2008 14:19'!
testContinuations
	"verify that process variable not copied by continuation."
	| x session context |
	session := WASession new.
	context := WARequestContext new.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 ifTrue: 
						[ self assert: WACurrentSession value == session.
						"invoke continuation for the first time - reuse process variables"
						savedContinuation value: 1 ].
					x == 1 ifTrue: 
						[ self assert: WACurrentSession value = session.
						WACurrentRequestContext reset.
						"invoke continuation for the second time - process variables reset"
						savedContinuation value: 2 ].
					"no value for WACurrentSession after continuation invoked for second time"
					self assert: x = 2.
					self assert: WACurrentSession value isNil ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 9/13/2008 14:19'!
testSimpleContinuation
	"verify that continuation reuses the process variable from the current process."
	| x continuation session context |
	session := WASession new.
	context := WARequestContext new.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						continuation := cc.
						false ].
					self assert: WACurrentSession value = session.
					x ifFalse: [ continuation value: true ].
					self assert: x ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 9/13/2008 14:19'!
testWithValue
	| session context |
	session := WASession new.
	context := WARequestContext new.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: [ self assert: WACurrentSession value = session ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'pmm 3/29/2008 12:35'!
testWithoutValue
	self assert: WACurrentSession value isNil! !

!WAPackage class methodsFor: '*Seaside-Tests-Session' stamp: 'lr 10/23/2008 21:36'!
seasideTestsSession
	^ self new
		name: 'Seaside-Tests-Session';
		description: 'Unit tests for the package Seaside-Session.';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Tests-Core';
		yourself! !

WARegistryTest subclass: #WAApplicationTest
	instanceVariableNames: 'request'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationTest methodsFor: 'running' stamp: 'jf 10/7/2008 01:36'!
newEntryPoint
	^ WAApplication named: 'app'! !

!WAApplicationTest methodsFor: 'running' stamp: 'jf 10/7/2008 00:48'!
setUp
	super setUp.
	request := WARequest new! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:45'!
testEmpty
	self assert: (handler sessionCookieFor: request) isNil! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:47'!
testOneOfMany
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOneOfManySlashInCookie
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3/';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOneOfManySlashInUrl
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOnlyOne
	| cookie1 cookie2 |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	request := WARequest
		method: 'GET'
		url: '/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array with: cookie1)
		remoteAddress: '127.0.0.1'.
	cookie2 := handler sessionCookieFor: request.
	self assert: cookie1 == cookie2! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testWrongKey
	| cookie |
	cookie := WARequestCookie key: '_k' value: '1234'.
	request := WARequest
		method: 'GET'
		url: '/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array with: cookie)
		remoteAddress: '127.0.0.1'.
	self assert: (handler sessionCookieFor: request) isNil! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testWrongPrefix
	| cookie1 cookie2 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/one';
		yourself.

	request := WARequest
		method: 'GET'
		url: '/oneo'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie1! !

WAContextTestCase subclass: #WAInteractionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAInteractionTest commentStamp: 'pmm 4/6/2008 15:22' prior: 0!
The purpose of WAInteractionTest is to provide a fully initialized WContext all the neccsary objects are are normally there in a Seaside application like request, response, dispatcher applicaion, session and so forth.!

!WAInteractionTest methodsFor: 'accessing' stamp: 'pmm 4/5/2008 16:10'!
application
	^self context application! !

!WAInteractionTest methodsFor: 'private' stamp: 'pmm 5/11/2008 09:27'!
configureContext: aRequestContext
	super configureContext: aRequestContext.
	aRequestContext request: WARequest blankRequest.
	aRequestContext response: WAResponse new! !

!WAInteractionTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 09:38'!
context
	^ WACurrentRequestContext value! !

!WAInteractionTest methodsFor: 'private' stamp: 'jf 9/29/2008 09:54'!
handlersToPush
	| dispatcher application session |
	dispatcher := WADispatcher named: 'rails'.
	application := (WAApplication named: 'homepage')
		setParent: dispatcher;
		yourself.
	session := WASession new.

	^super handlersToPush, (Array with: dispatcher with: application with: session)! !

!WAInteractionTest methodsFor: 'accessing' stamp: 'pmm 4/5/2008 16:08'!
session
	^self context session! !

!WAInteractionTest methodsFor: 'private' stamp: 'jf 9/22/2008 20:52'!
setCookie: aRequestCoookie
	self context request: (WARequest
		method: 'GET'
		url: WAUrl new
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array with: aRequestCoookie)
		remoteAddress: '127.0.0.1')! !

!WAInteractionTest methodsFor: 'testing' stamp: 'pmm 4/6/2008 15:27'!
testContentType
	| contentType |
	self application preferenceAt: #mimeType put: 'application/xhtml+xml'.
	self application preferenceAt: #charSet put: 'iso-8859-1'.
	
	contentType := WAResponse new contentType.
	self assert: contentType main = 'application'.
	self assert: contentType sub = 'xhtml+xml'.
	self assert: contentType charset = 'iso-8859-1'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'jf 9/29/2008 09:44'!
testDeleteNetscapeCookie
	| requestCookie responseCookies responseCookie |
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	requestCookie := WARequestCookie key: 'password' value: 'sex'.
	self setCookie: requestCookie.
	self context response deleteCookie: requestCookie.
	
	responseCookies := self context response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = self application baseUrl pathString! !

!WAInteractionTest methodsFor: 'testing' stamp: 'pmm 4/5/2008 16:47'!
testDeleteRfc2965Cookie
	| requestCookie responseCookies responseCookie |
	requestCookie := (WARequestCookie key: 'password' value: 'sex')
		path: '/en/private_kunden/wealth_management';
		version: 1;
		yourself.
	self setCookie: requestCookie.
	self context response deleteCookie: requestCookie.
	
	responseCookies := self context response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = '/en/private_kunden/wealth_management'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'jf 9/29/2008 09:43'!
testNewCookie
	| cookie |
	cookie := self context newCookie.
	self assert: cookie path = self application baseUrl pathString.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	cookie := self context newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPort put: 8080.
	self application preferenceAt: #serverProtocol put: 'https'.
	self application preferenceAt: #serverHostname put: 'www.lgt.com'.
	cookie := self context newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self deny: cookie ports isNil.
	self assert: cookie ports size = 1.
	self assert: cookie ports first = 8080.
	self assert: cookie httpOnly.
	self assert: cookie secure.
	self assert: cookie domain = 'www.lgt.com'! !
